@@ -1,41 +1,20 @@
-optiPair <-
-function (model = NULL, obs = NULL, pred = NULL,
+optiPair <- function (model = NULL, obs = NULL, pred = NULL,
           measures = c("Sensitivity", "Specificity"), 
           interval = 0.01, plot = TRUE, plot.sum = FALSE, 
-          plot.diff = FALSE, ylim = NULL, na.rm = TRUE, exclude.zeros = TRUE, ...) {
-  # version 1.9 (3 Dec 2021)
+          plot.diff = FALSE, ylim = NULL, na.rm = TRUE, exclude.zeros = TRUE, 
+          rm.dup = FALSE, ...) {
+  # version 2.1 (6 May 2022)
 
-  if(length(measures) != 2) stop ("'measures' must contain two elements.")
+  if (length(measures) != 2) stop ("'measures' must contain two elements.")
 
-  if(is.null(model)) {
-    
-    if (is.null(obs) | is.null(pred)) stop ("You must provide either the 'obs' and 'pred' vectors, or a 'model' object.")
-    if (length(obs) != length(pred))  stop ("'obs' and 'pred' must be of the same length (and in the same order).")
-    
-    dat <- data.frame(obs, pred)
-    n.in <- nrow(dat)
-    dat <- na.omit(dat)
-    n.out <- nrow(dat)
-    if (n.out < n.in)  warning (n.in - n.out, " observation(s) removed due to missing data; ", n.out, " observations actually evaluated.")
-    obs <- dat$obs
-    pred <- dat$pred
-    
-  } else { # end if null model
-  
-    #if(!("glm" %in% class(model) && model$family$family == "binomial" && model$family$link == "logit")) stop ("'model' must be an object of class 'glm' with 'binomial' family and 'logit' link.")
-    if (!is.null(obs)) message("Argument 'obs' ignored in favour of 'model'.")
-    if (!is.null(pred)) message("Argument 'pred' ignored in favour of 'model'.")
-    # obs <- model$y
-    # pred <- model$fitted.values
-    obspred <- mod2obspred(model)
-    obs <- obspred[ , "obs"]
-    pred <- obspred[ , "pred"]
-    
-    model <- NULL  # so the message is not repeated for each threshold
-  }  # end if model
+  obspred <- inputMunch(model, obs, pred, na.rm = na.rm, rm.dup = rm.dup)
+  obs <- obspred[ , "obs"]
+  pred <- obspred[ , "pred"]
+
+  # if (!is.null(model)) {
+  #   model <- NULL  # so the message is not repeated for each threshold
+  # }  # end if model
 
-  if (NA %in% obs | NA %in% pred) stop("Please remove (rows with) NA from your data")  # I think this is not realy used
-  if (length(obs) != length(pred)) stop("'obs' and 'pred' must have the same number of values (and in the same order)")
   if (!all(obs %in% c(0, 1))) stop ("'obs' must consist of binary observations of 0 or 1")
   if (any(pred < 0 | pred > 1)) stop ("'pred' must range between 0 and 1")
 
@@ -61,8 +40,8 @@ function (model = NULL, obs = NULL, pred = NULL,
 
     finite <- as.matrix(measures.values[ , 1:2])
     finite <- finite[is.finite(finite)]
-    if(is.null(ylim)) {
-      if(plot.sum) ylim <- c(min(finite), MaxSum)
+    if (is.null(ylim)) {
+      if (plot.sum) ylim <- c(min(finite), MaxSum)
       else ylim <- c(min(finite), max(finite))
     }  # end if null ylim
 
