@@ -1,11 +1,11 @@
-prevalence <-
-function (obs = NULL, model = NULL, event = 1, na.rm = TRUE) {
-  # version 1.3 (26 Nov 2021)
+prevalence <- function (obs = NULL, model = NULL, event = 1, na.rm = TRUE) {
+  # version 1.4 (2 May 2022)
 
   #model_classes_implemented <- c("glm", "gam", "gbm", "randomForest", "bart")
   #if (any(class(obs) %in% model_classes_implemented))  model <- obs  # (in case the user provides unnamed model argument)
   
   if (!is.null(obs)) {
+    obs <- unlist(obs)
     if (!is(obs, "vector") && !is(obs, "factor")) stop("'obs' must be of class 'vector' or 'factor'.")
       if (!(event %in% obs)) warning("'event' is not among of the values of 'obs'.")
   }
